@@ -10,6 +10,7 @@ from ..standard import b_data_standard2d
 
 class DataDict(TypedDict):
     num_classes: int
+    shape: tuple
     X_train: torch.Tensor
     y_train: torch.Tensor
     X_test: torch.Tensor
@@ -72,8 +73,11 @@ class Download_Base:
 
         X_train_standard, X_test_standard = self.standardization()
 
+        shape = self._get_shape()
+
         result: DataDict = dict(
             num_classes=self.num_classes,
+            shape=shape,
             X_train=X_train,
             y_train=y_train,
             X_test=X_test,
