@@ -1,7 +1,7 @@
-from .rnn import Layers_RNN, Spike_RNN
+from .rnn import Layers_RNN, Spike_RNN, Spike_RNN_With_T
 from .lstm import Layers_LSTM, Spike_LSTM, Spike_LSTM_With_T
 
 __all__ = [
-    'Layers_RNN', 'Spike_RNN',
+    'Layers_RNN', 'Spike_RNN', 'Spike_RNN_With_T',
     'Layers_LSTM', 'Spike_LSTM', 'Spike_LSTM_With_T'
 ]
\ No newline at end of file
