@@ -1,7 +1,7 @@
 import os
 import time
 from pathlib import Path
-from typing import Literal
+from typing import Literal, TypedDict
 
 import copy
 import torch
@@ -48,6 +48,9 @@ class _Func:
         result = self.func(**kwargs)
         return result
 
+class GPU_Dict(TypedDict):
+    total: int
+    max_used: int
 
 class B_Trainer:
     def __init__(
@@ -109,6 +112,10 @@ class B_Trainer:
         self.isSpikingjelly14 = isSpikingjelly14
         self.epoch = 0
         self.writer: B_Writer = None
+        self.gpu_dict:GPU_Dict = dict(
+            total=0,
+            max_used=0
+        )
 
         if not callable(inputs_func) or not callable(outputs_func) or not callable(labels_func):
             raise ValueError("inputs_func, outputs_func, labels_func必须为可调用对象")
@@ -324,6 +331,9 @@ class B_Trainer:
         )
 
     def get_metric_lists(self):
+        '''
+        获取指标列表
+        '''
         result = (
             self.train_loss_batches_lst,
             self.train_loss_epoch_lst,
@@ -332,6 +342,9 @@ class B_Trainer:
         )
         return result
 
+    def get_GPU_dict(self) -> GPU_Dict:
+        return self.gpu_dict
+
     def calculate_model(self, dataloader=None, model=None, inputs_func=None, outputs_func=None, labels_func=None):
         '''
         如果不指定, 则用类内的
@@ -484,6 +497,7 @@ class B_Trainer:
                 case "continue":
                     pass
 
+
     def _train_once(self, epoch, epochs):
         bar = B_Tqdm(range=len(self.train_loader))
         current_lr = self.optimizer.param_groups[0]['lr']
@@ -530,6 +544,8 @@ class B_Trainer:
         if self.device == torch.device('cuda'):
             gpu = b_get_gpu_nvidia()[0]
             usage = f' (GPU: {gpu[-2]}/{gpu[-1]}) '
+            if gpu[-2] > self.gpu_dict['max_used']:
+                self.gpu_dict['max_used'] = gpu[-2]
         elif self.device == torch.device('cpu'):
             # 获取cpu的使用率
             usage = ' (CPU) '
