@@ -4,13 +4,15 @@ import warnings
 import traceback
 import time
 from byzh.core.Bwriter import B_Writer
+from byzh.core import B_os
+
 class B_GridFunc():
     def __init__(
             self,
             _mode:Literal["product", "zip"] = "product",
             _run_verbose=False,
             _log_path=None,
-            **kwargs: Sequence
+            **kwargs
     ):
         '''
         :param mode: "product": 所有情况, "zip": 对应情况
@@ -19,7 +21,13 @@ class B_GridFunc():
         self._mode = _mode
         self._run_verbose = _run_verbose
         self._log_path = _log_path
-        self._writer = B_Writer(self._log_path) if self._log_path else None
+        if self._log_path:
+            self._writer = B_Writer(self._log_path)
+            # 写入`调用该类的文件名`
+            file_name = B_os.get_main_file()[1]
+            self._writer.toFile(f"{file_name}:")
+        else:
+            self._writer = None
         self._all_keys = []
         self._attribute_keys = []
 
@@ -97,6 +105,7 @@ class B_GridFunc():
                 traceback.print_exc()
             # 记录
             if self._run_verbose:
+                print("=" * 50)
                 print(f"[B_GridFunc] 第{i+1}/{total}次迭代{flag}")
                 print(f"[B_GridFunc] 其参数为:")
                 for key in self._all_keys:
@@ -105,6 +114,7 @@ class B_GridFunc():
                         content = content[:50] + "..."
                     print(f"------------ \t{key}={content}")
             if self._writer:
+                self._writer.toFile("=" * 50)
                 self._writer.toFile(f"[B_GridFunc] 第{i + 1}/{total}次迭代{flag}")
                 self._writer.toFile(f"[B_GridFunc] 其参数为:")
                 for key in self._all_keys:
